<?php
namespace finc\Module\Configuration;

$config = [
    'service_manager' => [
        'factories' => [
            'finc\Cache\Manager' => 'VuFind\Cache\ManagerFactory',
            'finc\Config\BranchesReader' => 'VuFind\Config\YamlReaderFactory',
            'finc\ILS\Connection' => 'VuFind\ILS\ConnectionFactory',
            'finc\ILS\Logic\Holds' => 'VuFind\ILS\Logic\LogicFactory',
            'finc\Rewrite\EblRewrite' => 'finc\Rewrite\EblRewriteFactory',
        ],
        'delegators' => [
            'VuFindSearch\Service' => [
                'finc\Service\MungerInjectionDelegatorFactory'
            ],
        ],
        'aliases' => [
            'VuFind\Cache\Manager' => 'finc\Cache\Manager',
            'VuFind\ILS\Connection' => 'finc\ILS\Connection',
            'VuFind\ILS\Logic\Holds' => 'finc\ILS\Logic\Holds',
        ]
    ],
    'controllers' => [
        'factories' => [
            'finc\Controller\MyResearchController' => 'VuFind\Controller\AbstractBaseFactory',
            'finc\Controller\RecordController' => 'VuFind\Controller\AbstractBaseWithConfigFactory',
            'finc\Controller\AmslResourceController' => 'finc\Controller\AmslResourceControllerFactory',
            'finc\Controller\DocumentDeliveryServiceController' => 'finc\Controller\DocumentDeliveryServiceControllerFactory',
        ],
        'aliases' => [
            'resources' => 'Resources',
            'Resources' => 'finc\Controller\AmslResourceController',
            'dds' => 'finc\Controller\DocumentDeliveryServiceController',
            'VuFind\Controller\MyResearchController' => 'finc\Controller\MyResearchController',
            'VuFind\Controller\RecordController' => 'finc\Controller\RecordController',
        ],
    ],
    'controller_plugins' => [
        'factories' => [
            'finc\Controller\Plugin\EmailHold' => 'finc\Controller\Plugin\EmailHoldFactory',
        ],
        'aliases' => [
            'emailHold' => 'finc\Controller\Plugin\EmailHold'
        ]
    ],
    'vufind' => [
        'plugin_managers' => [
            'ajaxhandler' => [
                'factories' => [
                    'finc\AjaxHandler\GetAdditionalAccountInfo' =>
                        'VuFind\AjaxHandler\AbstractIlsAndUserActionFactory',
                    'finc\AjaxHandler\GetIlsStatus' =>
                        'VuFind\AjaxHandler\GetIlsStatusFactory',
                    'finc\AjaxHandler\GetItemStatuses' =>
                        'VuFind\AjaxHandler\GetItemStatusesFactory',
                    'finc\AjaxHandler\GetResolverLinks' =>
                        'finc\AjaxHandler\GetResolverLinksFactory'
                ],
                'aliases' => [
                    'getAdditionalAccountInfo' =>
                        'finc\AjaxHandler\GetAdditionalAccountInfo',
                    'getIlsStatus' =>
                        'finc\AjaxHandler\GetIlsStatus',
                    'getItemStatuses' =>
                        'finc\AjaxHandler\GetItemStatuses',
                    'getResolverLinks' =>
                        'finc\AjaxHandler\GetResolverLinks'
                ]
            ],
            'ils_driver' => [
                'factories' => [
                    'finc\ILS\Driver\FincILS' => 'finc\ILS\Driver\Factory::getFincILS',
                    'finc\ILS\Driver\PAIA' => 'finc\ILS\Driver\Factory::getPAIA',
                    //finctheca is deprecated: Remove when Bibliotheca support ends
                    'finc\ILS\Driver\FincTheca' => 'finc\ILS\Driver\Factory::GetFincTheca'
                ],
                'aliases' => [
                    'fincils' => 'finc\ILS\Driver\FincILS',
                    'paia' => 'finc\ILS\Driver\PAIA',
                    'finctheca' => 'finc\ILS\Driver\FincTheca',
                ],
            ],
            'recommend' => [
                'factories' => [
                    'finc\Recommend\EbscoResults' => 'finc\Recommend\Factory::getEbscoResults',
                ],
                'aliases' => [
                    'ebscoresults' => 'finc\Recommend\EbscoResults',
                ]
            ],
            'recorddriver' => [
                'factories' => [
                    'finc\RecordDriver\SolrDefault' => 'finc\RecordDriver\Factory::getSolrDefault',
                    'finc\RecordDriver\SolrMarc' => 'finc\RecordDriver\Factory::getSolrMarc',
                    'finc\RecordDriver\SolrMarcFinc' => 'finc\RecordDriver\Factory::getSolrMarcFinc',
                    'finc\RecordDriver\SolrMarcFincPDA' => 'finc\RecordDriver\Factory::getSolrMarcFincPDA',
                    'finc\RecordDriver\SolrMarcRemote' => 'finc\RecordDriver\Factory::getSolrMarcRemote',
                    'finc\RecordDriver\SolrMarcRemoteFinc' => 'finc\RecordDriver\Factory::getSolrMarcRemoteFinc',
                    'finc\RecordDriver\SolrAI' => 'finc\RecordDriver\Factory::getSolrAI',
                    'finc\RecordDriver\SolrIS' => 'finc\RecordDriver\Factory::getSolrIS',
                    'finc\RecordDriver\SolrLido' => 'finc\RecordDriver\Factory::getSolrLido',
                    'finc\RecordDriver\SolrLidoNdl' => 'finc\RecordDriver\Factory::getSolrLidoNdl',
                    'finc\RecordDriver\SolrDico' => 'finc\RecordDriver\Factory::getSolrDico',
                ],
                'aliases' => [
                    'VuFind\RecordDriver\SolrDefault' => 'finc\RecordDriver\SolrDefault',
                    'VuFind\RecordDriver\SolrMarc' => 'finc\RecordDriver\SolrMarc',
                    'solrmarcfinc' => 'finc\RecordDriver\SolrMarcFinc',
                    'solrmarcfincpda' => 'finc\RecordDriver\SolrMarcFincPDA',
                    'VuFind\RecordDriver\SolrMarcRemote' => 'finc\RecordDriver\SolrMarcRemote',
                    'solrmarcremotefinc' => 'finc\RecordDriver\SolrMarcRemoteFinc',
                    'solrai' => 'finc\RecordDriver\SolrAI',
                    'solris' => 'finc\RecordDriver\SolrIS',
                    'solrlido' => 'finc\RecordDriver\SolrLido',
                    'solrlidondl' => 'finc\RecordDriver\SolrLidoNdl',
                    'solrdico' => 'finc\RecordDriver\SolrDico',
                ],
            ],
            'recordtab' => [
                'factories' => [
                    'finc\RecordTab\StaffViewAI' => 'Zend\ServiceManager\Factory\InvokableFactory',
                    'finc\RecordTab\AcquisitionPDA' => 'Zend\ServiceManager\Factory\InvokableFactory',
                    'finc\RecordTab\Topics' => 'Zend\ServiceManager\Factory\InvokableFactory',
                    'finc\RecordTab\DescriptionLido' => 'Zend\ServiceManager\Factory\InvokableFactory',
                    'finc\RecordTab\HierarchyTree' => 'VuFind\RecordTab\Factory::getHierarchyTree',
                ],
                'aliases' => [
                    'VuFind\RecordTab\HierarchyTree' => 'finc\RecordTab\HierarchyTree',
                    'staffviewai' => 'finc\RecordTab\StaffViewAI',
                    'acquisitionpda' => 'finc\RecordTab\AcquisitionPDA',
                    'topics' => 'finc\RecordTab\Topics',
                    'descriptionlido' => 'finc\RecordTab\DescriptionLido',
                ],
            ],
            'resolver_driver' => [
                'factories' => [
                    'finc\Resolver\Driver\Ezb' => 'finc\Resolver\Driver\FincResolverDriverFactory',
                    'finc\Resolver\Driver\Redi' => 'finc\Resolver\Driver\FincResolverDriverFactory'
                ],
                'aliases' => [
                    'ezb' => 'finc\Resolver\Driver\Ezb',
                    'redi' => 'finc\Resolver\Driver\Redi'
                ]
            ],
            'hierarchy_treedataformatter' => [
                'factories' => [
                    'finc\Hierarchy\TreeDataFormatter\NoCollections' =>
                        'Zend\ServiceManager\Factory\InvokableFactory',
                ],
                'aliases' => [
                    'json' => 'finc\Hierarchy\TreeDataFormatter\NoCollections',
                ],
            ],
            'hierarchy_treedatasource' => [
                'factories' => [
                    'finc\Hierarchy\TreeDataSource\Solr' => 'VuFind\Hierarchy\TreeDataSource\SolrFactory',
                ],
                'aliases' => [
                    'solr' => 'finc\Hierarchy\TreeDataSource\Solr',
                ],
            ],
            'hierarchy_treerenderer' => [
                'factories' => [
                    'finc\Hierarchy\TreeRenderer\JSTree' => 'VuFind\Hierarchy\TreeRenderer\JSTreeFactory'
                ],
                'aliases' => [
                    'jstree' => 'finc\Hierarchy\TreeRenderer\JSTree'
                ],
            ],
        ],
        'recorddriver_tabs' => [
            'finc\RecordDriver\SolrDefault' => [
                'tabs' => [
                    'Holdings' => 'HoldingsILS', 'Description' => 'Description',
                    'TOC' => 'TOC', 'UserComments' => 'UserComments',
                    'Reviews' => 'Reviews', 'Excerpt' => 'Excerpt',
                    'Preview' => 'preview',
                    'HierarchyTree' => 'HierarchyTree', 'Map' => 'Map',
                    'Similar' => null,
                    'Details' => 'StaffViewArray',
                ],
                'defaultTab' => null,
            ],
            'finc\RecordDriver\SolrMarc' => [
                'tabs' => [
                    'Holdings' => 'HoldingsILS', 'Description' => 'Description',
                    'TOC' => 'TOC', 'UserComments' => 'UserComments',
                    'Reviews' => 'Reviews', 'Excerpt' => 'Excerpt',
                    'Preview' => 'preview',
                    'HierarchyTree' => 'HierarchyTree', 'Map' => 'Map',
                    'Similar' => null,
                    'Details' => 'StaffViewMARC',
                ],
                'defaultTab' => null,
            ],
            'finc\RecordDriver\SolrMarcFincPDA' => [
                'tabs' => [
                    /* 'Holdings' => 'HoldingsILS',*/
                    'AcquisitionPDA' => 'AcquisitionPDA',
                    'Description' => 'Description',
                    'TOC' => 'TOC', 'UserComments' => 'UserComments',
                    'Reviews' => 'Reviews', 'Excerpt' => 'Excerpt',
                    'Preview' => 'preview',
                    'HierarchyTree' => 'HierarchyTree', 'Map' => 'Map',
                    'Similar' => null,
                    'Details' => 'StaffViewMARC',
                ],
                'defaultTab' => null,
            ],
            'finc\RecordDriver\SolrAI' => [
                'tabs' => [
                    'Holdings' => 'HoldingsILS', 'Description' => 'Description',
                    'TOC' => 'TOC', 'UserComments' => 'UserComments',
                    'Reviews' => 'Reviews', 'Excerpt' => 'Excerpt',
                    'Preview' => 'preview',
                    'HierarchyTree' => 'HierarchyTree', 'Map' => 'Map',
                    'Similar' => null,
                    'Details' => 'StaffViewAI',
                ],
                'defaultTab' => null,
            ],
            'finc\RecordDriver\SolrLido' => [
                'tabs' => [
                    'Holdings' => 'HoldingsILS', 'Description' => 'DescriptionLido',
                    'Reviews' => 'Reviews', 'Excerpt' => 'Excerpt',
                    'Preview' => 'preview', 'Map' => 'Map',
                    'Similar' => 'SimilarItemsCarousel',
                    'Details' => 'StaffViewArray',
                ],
                'defaultTab' => null,
            ],
        ],
        'recorddriver_collection_tabs' => [
            'VuFind\RecordDriver\AbstractBase' => [
                'tabs' => [
                    'CollectionList' => 'CollectionList',
                    'HierarchyTree' => 'CollectionHierarchyTree',
                    'Details' => 'StaffViewArray',
                ],
                'defaultTab' => null,
            ],
            'finc\RecordDriver\SolrDico' => [
                'tabs' => [
                    'CollectionList' => 'CollectionList',
                    'HierarchyTree' => 'HierarchyTree',
                    'Details' => 'StaffViewArray',
                ],
                'defaultTab' => 'CollectionList',
            ],
        ],
    ],
    // Authorization configuration:
    'zfc_rbac' => [
        'vufind_permission_provider_manager' => [
            'factories' => [
                //'catUserType' => 'finc\Role\PermissionProvider\Factory::getCatUserType',
                //'ipRangeFoFor' => 'finc\Role\PermissionProvider\Factory::getIpRangeFoFor',
                //'ipRegExFoFor' => 'finc\Role\PermissionProvider\Factory::getIpRegExFoFor' ,
                'finc\Role\PermissionProvider\CatUserType' =>
                    'finc\Role\PermissionProvider\Factory::getCatUserType',
                'finc\Role\PermissionProvider\IpRangeFoFor' =>
                    'finc\Role\PermissionProvider\Factory::getIpRangeFoFor',
                'finc\Role\PermissionProvider\IpRegExFoFor' =>
                    'finc\Role\PermissionProvider\Factory::getIpRegExFoFor'
            ],
            'aliases' => [
                'CatUserType' => 'finc\Role\PermissionProvider\CatUserType',
                'IpRangeFoFor' => 'finc\Role\PermissionProvider\IpRangeFoFor',
                'IpRegExFoFor' => 'finc\Role\PermissionProvider\IpRegExFoFor',
                'IpRange' => 'VuFind\Role\PermissionProvider\IpRange',
            ]
        ]
    ],
];

$nonTabRecordActions = [
    'PDA', 'EmailHold', 'ReportErrors'
];


// Define record view routes -- route name => controller
// Define record view routes once again to add new nonTabRecordActions
$recordRoutes = [
    'record' => 'Record',
    'resources' => 'Resources'
];


// Define static routes -- Controller/Action strings
$staticRoutes = [
    'MyResearch/Acquisition',
    'MyResearch/ResetPassword',
    'dds/Home',
    'dds/Email',
    'Record/EblLink'
];

$routeGenerator = new \VuFind\Route\RouteGenerator($nonTabRecordActions);
$routeGenerator->addRecordRoutes($config, $recordRoutes);
$routeGenerator->addStaticRoutes($config, $staticRoutes);

return $config;
